package net.knarcraft.bookswithoutborders.utility;

import net.knarcraft.bookswithoutborders.BooksWithoutBorders;
import net.knarcraft.bookswithoutborders.config.BooksWithoutBordersConfig;
import org.bukkit.entity.Player;
import org.bukkit.inventory.meta.BookMeta;

import static net.knarcraft.bookswithoutborders.utility.InputCleaningHelper.cleanString;
import static net.knarcraft.bookswithoutborders.utility.InputCleaningHelper.fixName;

/**
 * Helper class for getting abstract book information
 */
public final class BookHelper {

    private BookHelper() {

    }

    /**
     * Gets the file name of the given book
     *
     * @param book   <p>The book to get the file of</p>
     * @param player <p>The player trying to do something with the book</p>
     * @return <p>The book file</p>
     */
    public static String getBookFile(BookMeta book, Player player) {
        String titleAuthorSeparator = BooksWithoutBordersConfig.getTitleAuthorSeparator();
        String bookName;
        if (!book.hasTitle()) {
            bookName = book.getTitle();
        } else {
            bookName = "Untitled";
        }

        String authorName;
        if (book.hasAuthor()) {
            authorName = book.getAuthor();
        } else {
            authorName = player.getName();
        }

        return fixName(cleanString(bookName + titleAuthorSeparator + authorName), false);
    }

    /**
     * Checks whether the given player is the author of a given book
     *
     * @param player <p>The player to check</p>
     * @param book   <p>The book to check</p>
     * @return <p>True if the player is not the book's author</p>
     */
    public static boolean isNotAuthor(Player player, BookMeta book) {
        String author = book.getAuthor();
        String playerName = InputCleaningHelper.cleanString(player.getName());
        if (author != null && playerName.equalsIgnoreCase(InputCleaningHelper.cleanString(author))) {
            return false;
        }

        BooksWithoutBorders.sendErrorMessage(player, "You must be the author of this book to use this command!");
        return true;
    }

}
